@@ -18,7 +18,7 @@
  *   51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.             *
  ***************************************************************************/
 #include "singledatachecker.h"
-#include <klocale.h>
+#include <klocalizedstring.h>
 #include <util/log.h>
 #include <util/file.h>
 #include <util/error.h>
