@@ -42,7 +42,7 @@ class ChunkManagerTest : public QObject
 {
 	Q_OBJECT
 	
-private slots:
+private Q_SLOTS:
 	void initTestCase()
 	{
 		QLocale::setDefault(QLocale("main"));
