@@ -64,17 +64,16 @@ namespace bt
 
 		if (!aman.allowed(sock->getRemoteAddress()))
 		{
-			Out(SYS_GEN|LOG_DEBUG) << "The IP address " << sock->getRemoteIPAddress() << " is blocked" << endl;
+			Out(SYS_GEN|LOG_NOTICE) << "The IP address " << sock->getRemoteIPAddress() << " is blocked" << endl;
 			onFinish(false);
 			return;
 		}
 		
-		// try to find a PeerManager which has te right info hash
+		// try to find a PeerManager which has the right info hash
 		SHA1Hash rh(hs+28);
 		PeerManager* pman = ServerInterface::findPeerManager(rh);
 		if (!pman)
 		{
-			Out(SYS_GEN|LOG_DEBUG) << "Cannot find PeerManager for hash : " << rh.toString() << endl;
 			onFinish(false);
 			return;
 		}
@@ -116,4 +115,3 @@ namespace bt
 	}
 }
 
-#include "serverauthenticate.moc"
