@@ -20,18 +20,17 @@
 #include "udptracker.h"
 #include <stdlib.h>
 #include <arpa/inet.h>
-#include <klocale.h>
+#include <klocalizedstring.h>
 #include <util/functions.h>
 #include <util/log.h>
-#include <k3socketaddress.h>
-#include <k3resolver.h>
+#include <net/addressresolver.h>
 #include <peer/peermanager.h>
 #include <interfaces/torrentinterface.h>
 #include <torrent/globals.h>
 #include <torrent/server.h>
 #include "udptrackersocket.h"
 
-using namespace KNetwork;
+
 
 namespace bt
 {
@@ -40,31 +39,29 @@ namespace bt
 	Uint32 UDPTracker::num_instances = 0;
 	
 
-	UDPTracker::UDPTracker(const KUrl & url,TrackerDataSource* tds,const PeerID & id,int tier) 
-	: Tracker(url,tds,id,tier)
+	UDPTracker::UDPTracker(const QUrl &url,TrackerDataSource* tds,const PeerID & id,int tier)
+		: Tracker(url,tds,id,tier)
+		, connection_id(0)
+		, transaction_id(0)
+		, scrape_transaction_id(0)
+		, data_read(0)
+		, failures(0)
+		, resolved(false)
+		, todo(NOTHING)
+		, event(NONE)
 	{
 		num_instances++;
 		if (!socket)
 			socket = new UDPTrackerSocket();
 		
-		connection_id = 0;
-		transaction_id = 0;
 		interval = 0;
-		scrape_transaction_id = 0;
-		todo = NOTHING;
 		
 		conn_timer.setSingleShot(true);
-		connect(&conn_timer,SIGNAL(timeout()),this,SLOT(onConnTimeout()));
-		connect(socket,SIGNAL(announceReceived(Int32, const QByteArray & )),
-				this,SLOT(announceReceived(Int32, const QByteArray & )));
-		connect(socket,SIGNAL(connectReceived(Int32, Int64 )),
-				this,SLOT(connectReceived(Int32, Int64 )));
-		connect(socket,SIGNAL(error(Int32, const QString& )),
-				this,SLOT(onError(Int32, const QString& )));
-		connect(socket,SIGNAL(scrapeReceived(Int32,QByteArray)),
-				this,SLOT(scrapeReceived(Int32,QByteArray)));
-		
-		resolved = false;
+		connect(&conn_timer, &QTimer::timeout, this, &UDPTracker::onConnTimeout);
+		connect(socket, &UDPTrackerSocket::announceReceived, this, &UDPTracker::announceReceived);
+		connect(socket, &UDPTrackerSocket::connectReceived, this, &UDPTracker::connectReceived);
+		connect(socket, &UDPTrackerSocket::error, this, &UDPTracker::onError);
+		connect(socket, &UDPTrackerSocket::scrapeReceived, this, &UDPTracker::scrapeReceived);
 	}
 
 
@@ -138,12 +135,11 @@ namespace bt
 			sendScrape();
 	}
 	
-	void UDPTracker::announceReceived(Int32 tid,const QByteArray & b)
+	void UDPTracker::announceReceived(Int32 tid,const bt::Uint8* buf,bt::Uint32 size)
 	{
-		if (tid != transaction_id || b.size() < 20)
+		if (tid != transaction_id || size < 20)
 			return;
 
-		Uint8* buf = (Uint8*)b.data();
 		/*
 		0  32-bit integer  action  1
 		4  32-bit integer  transaction_id
@@ -160,15 +156,10 @@ namespace bt
 
 		Uint32 nip = leechers + seeders;
 		Uint32 j = 0;
-		for (int i = 20;i < b.size() && j < nip;i+=6,j++)
+		for (Uint32 i = 20;i < size && j < nip;i+=6,j++)
 		{
 			Uint32 ip = ReadUint32(buf,i);
-			QString ip_str = QString("%1.%2.%3.%4")
-				.arg((ip & 0xFF000000) >> 24)
-				.arg((ip & 0x00FF0000) >> 16)
-				.arg((ip & 0x0000FF00) >> 8)
-				.arg(ip & 0x000000FF);
-			addPeer(ip_str,ReadUint16(buf,i+4));
+			addPeer(net::Address(ip, ReadUint16(buf,i+4)), false);
 		}
 		
 		peersReady(this);
@@ -209,8 +200,8 @@ namespace bt
 		if (!resolved)
 		{
 			todo |= ANNOUNCE_REQUEST;
-			KResolver::resolveAsync(this,SLOT(onResolverResults(KNetwork::KResolverResults )),
-									url.host(),QString::number(url.port(80)));
+			net::AddressResolver::resolve(url.host(), url.port(80), 
+										  this, SLOT(onResolverResults(net::AddressResolver*)));
 		}
 		else if (connection_id == 0)
 		{
@@ -234,8 +225,8 @@ namespace bt
 		if (!resolved)
 		{
 			todo |= SCRAPE_REQUEST;
-			KResolver::resolveAsync(this,SLOT(onResolverResults(KNetwork::KResolverResults )),
-									url.host(),QString::number(url.port(80)));
+			net::AddressResolver::resolve(url.host(), url.port(80), 
+										  this, SLOT(onResolverResults(net::AddressResolver*)));
 		}
 		else if (connection_id == 0)
 		{
@@ -249,7 +240,7 @@ namespace bt
 		}
 	}
 
-	void UDPTracker::scrapeReceived(Int32 tid, const QByteArray& b)
+	void UDPTracker::scrapeReceived(Int32 tid, const Uint8* buf, Uint32 size)
 	{
 		/*
 		0				32-bit integer	action	2
@@ -259,10 +250,9 @@ namespace bt
 		16 + 12 * n		32-bit integer	leechers
 		8 + 12 * N 
 		*/
-		if (tid != scrape_transaction_id || b.size() < 20)
+		if (tid != scrape_transaction_id || size < 20)
 			return;
 		
-		Uint8* buf = (Uint8*)b.data();
 		seeders = ReadInt32(buf,8);
 		total_downloaded = ReadInt32(buf,12);
 		leechers = ReadInt32(buf,16);
@@ -325,8 +315,8 @@ namespace bt
 		}
 		else
 		{
-			KNetwork::KIpAddress addr(cip);
-			WriteUint32(buf,84,ntohl(addr.IPv4Addr(true)));
+			net::Address addr(cip, 999);
+			WriteUint32(buf,84,addr.toIPv4Address());
 		}
 		WriteUint32(buf,88,key);
 		if (ev != STOPPED)
@@ -368,7 +358,7 @@ namespace bt
 			connection_id = 0;
 			failures++;
 			if (event != STOPPED)
-				onError(transaction_id,i18n("Timeout contacting tracker %1",url.prettyUrl()));
+				onError(transaction_id,i18n("Timeout contacting tracker %1",url.toDisplayString()));
 			else
 			{
 				status = TRACKER_IDLE;
@@ -378,15 +368,15 @@ namespace bt
 		else
 		{
 			failures++;
-			onError(transaction_id,i18n("Timeout contacting tracker %1",url.prettyUrl()));
+			onError(transaction_id,i18n("Timeout contacting tracker %1",url.toDisplayString()));
 		}
 	}
 
-	void UDPTracker::onResolverResults(KResolverResults res)
+	void UDPTracker::onResolverResults(net::AddressResolver* ar)
 	{
-		if (res.count() > 0)
+		if (ar->succeeded())
 		{
-			address = res.front().address();
+			address = ar->address();
 			resolved = true;
 			// continue doing request
 			if (connection_id == 0)
@@ -410,4 +400,3 @@ namespace bt
 	}
 	
 }
-#include "udptracker.moc"
