@@ -17,11 +17,17 @@
  *   Free Software Foundation, Inc.,                                       *
  *   51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.          *
  ***************************************************************************/
-#include <stdlib.h>
+
+#include <cstdlib>
+
 #include <QDir>
+#include <QDomElement>
+#include <QNetworkRequest>
 #include <QStringList>
-#include <klocalizedstring.h>
-#include <kio/job.h>
+
+#include <KIO/Job>
+#include <KLocalizedString>
+
 #include <torrent/globals.h>
 #include <util/log.h>
 #include <util/array.h>
@@ -35,7 +41,6 @@
 #include "upnpdescriptionparser.h"
 #include "soap.h"
 #include "httprequest.h"
-#include <QDomElement>
 
 using namespace net;
 
@@ -130,7 +135,7 @@ namespace bt
         else if(name == "modelName")
             modelName = value;
         else if(name == "modelNumber")
-            modelNumber == value;
+            modelNumber = value;
     }
 
     ///////////////////////////////////////
@@ -150,7 +155,7 @@ namespace bt
 
     void UPnPRouter::addService(const UPnPService& s)
     {
-        foreach(const UPnPService& os, d->services)
+        for (const UPnPService& os : qAsConst(d->services))
         {
             if(s.servicetype == os.servicetype)
                 return;
@@ -200,7 +205,7 @@ namespace bt
         bool found = false;
         Out(SYS_PNP | LOG_NOTICE) << "Forwarding port " << port.number << " (" << (port.proto == UDP ? "UDP" : "TCP") << ")" << endl;
         // first find the right service
-        foreach(const UPnPService& s, d->services)
+        for (const UPnPService& s : qAsConst(d->services))
         {
             if(s.servicetype.contains("WANIPConnection") || s.servicetype.contains("WANPPPConnection"))
             {
@@ -236,7 +241,7 @@ namespace bt
             }
             else
             {
-                itr++;
+                ++itr;
             }
         }
 
@@ -283,7 +288,7 @@ namespace bt
                 {
                     d->external_ip = nodes.item(0).firstChild().nodeValue();
                     Out(SYS_PNP | LOG_DEBUG) << "UPnP: External IP: " << d->external_ip << endl;
-                    // Keep track of external IP so AccessManager can block it, makes no sense to connect to ourself
+                    // Keep track of external IP so AccessManager can block it, makes no sense to connect to ourselves
                     AccessManager::instance().addExternalIP(d->external_ip);
                 }
                 else
@@ -370,7 +375,7 @@ namespace bt
 
     void UPnPRouter::visit(UPnPRouter::Visitor* visitor) const
     {
-        foreach(const Forwarding& fwd, d->fwds)
+        for (const Forwarding& fwd : qAsConst(d->fwds))
         {
             visitor->forwarding(fwd.port, fwd.pending_req != 0, fwd.service);
         }
@@ -386,9 +391,8 @@ namespace bt
 
     UPnPRouter::UPnPRouterPrivate::~UPnPRouterPrivate()
     {
-        foreach(HTTPRequest* r, active_reqs)
+        for (HTTPRequest* r : qAsConst(active_reqs))
         {
-            r->cancel();
             r->deleteLater();
         }
     }
@@ -405,27 +409,19 @@ namespace bt
         QString host = !ctrlurl.host().isEmpty() ? ctrlurl.host() : location.host();
         bt::Uint16 port = ctrlurl.port() != -1 ? ctrlurl.port() : location.port(80);
 
-        QString http_hdr;
-        QTextStream out(&http_hdr);
-        QString encoded_query = ctrlurl.query();
-        if(encoded_query.isEmpty())
-            out << "POST " << ctrlurl.path() << " HTTP/1.1\r\n";
-        else
-            out << "POST " << ctrlurl.path() << "?" << encoded_query << " HTTP/1.1\r\n";
-        out << "Host: " << host << ":" << port << "\r\n";
-        out << "User-Agent: " << bt::GetVersionString() << "\r\n";
-        out << "Content-length: $CONTENT_LENGTH\r\n";
-        out << "Content-Type: text/xml\r\n";
-        out << "SOAPAction: \"" << soapact << "\"\r\n\r\n";
+        QNetworkRequest networkReq;
+        networkReq.setUrl(ctrlurl);
+        networkReq.setRawHeader("Host", host.toLatin1() + QByteArrayLiteral(":") + QByteArray::number(port));
+        networkReq.setRawHeader("User-Agent", bt::GetVersionString().toLatin1());
+        networkReq.setHeader(QNetworkRequest::ContentTypeHeader, QLatin1String("text/xml"));
+        networkReq.setRawHeader("SOAPAction", soapact.toLatin1());
 
-        HTTPRequest* r = new HTTPRequest(http_hdr, query, host, port, verbose);
+        HTTPRequest* r = new HTTPRequest(networkReq, query, host, port, verbose);
         if(!at_exit)
         {
             // Only listen for results when we are not exiting
             active_reqs.append(r);
         }
-
-        r->start();
         return r;
     }
 
@@ -480,7 +476,7 @@ namespace bt
             if(fwo.port == port && fwo.service == srv)
                 itr = fwds.erase(itr);
             else
-                itr++;
+                ++itr;
         }
 
         fw.pending_req = sendSoapQuery(comm, srv->servicetype + "#" + action, srv->controlurl);
@@ -519,7 +515,7 @@ namespace bt
 
     void UPnPRouter::UPnPRouterPrivate::getExternalIP()
     {
-        foreach(const UPnPService& s, services)
+        for (const UPnPService& s : qAsConst(services))
         {
             if(s.servicetype.contains("WANIPConnection") || s.servicetype.contains("WANPPPConnection"))
             {
@@ -545,7 +541,7 @@ namespace bt
                     fwds.erase(i);
                 break;
             }
-            i++;
+            ++i;
         }
 
         active_reqs.removeAll(r);
