@@ -17,7 +17,9 @@
  *   Free Software Foundation, Inc.,                                       *
  *   51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.          *
  ***************************************************************************/
-#include <KLocale>
+#include <klocalizedstring.h>
+#include <sys/socket.h>
+#include <unistd.h>
 #include "signalcatcher.h"
 #include "log.h"
 
@@ -28,7 +30,7 @@ namespace bt
 	sigjmp_buf sigbus_env;
 	static bool siglongjmp_safe = false;
 	
-	static void signal_handler(int sig, siginfo_t *siginfo, void *ptr)
+	static void sigbus_handler(int sig, siginfo_t *siginfo, void *ptr)
 	{
 		Q_UNUSED(siginfo);
 		Q_UNUSED(ptr);
@@ -45,11 +47,11 @@ namespace bt
 		
 		memset(&act, 0, sizeof(act));
 		
-		if (sigaction(SIGBUS, 0, &act) != -1 && act.sa_sigaction == signal_handler)
+		if (sigaction(SIGBUS, 0, &act) != -1 && act.sa_sigaction == sigbus_handler)
 			return true;
 		
 		
-		act.sa_sigaction = signal_handler;
+		act.sa_sigaction = sigbus_handler;
 		act.sa_flags = SA_SIGINFO;
 		
 		if (sigaction(SIGBUS, &act, 0) == -1) 
@@ -80,11 +82,60 @@ namespace bt
 	{
 
 	}
+	
 	BusError::~BusError()
 	{
 
 	}
 
+	int SignalCatcher::signal_received_pipe[2];
+
+	SignalCatcher::SignalCatcher(QObject* parent) 
+		: QObject(parent),
+		notifier(0)
+	{
+		socketpair(AF_UNIX, SOCK_STREAM, 0, signal_received_pipe);
+		notifier = new QSocketNotifier(signal_received_pipe[1], QSocketNotifier::Read, this);
+		connect(notifier, SIGNAL(activated(int)), this, SLOT(handleInput(int)));
+	}
+
+	SignalCatcher::~SignalCatcher()
+	{
+	}
+	
+	void SignalCatcher::signalHandler(int sig, siginfo_t* siginfo, void* ptr)
+	{
+		Q_UNUSED(siginfo);
+		Q_UNUSED(ptr);
+		::write(signal_received_pipe[0], &sig, sizeof(int));
+	}
+
+	
+	bool SignalCatcher::catchSignal(int sig)
+	{
+		struct sigaction act;
+		memset(&act, 0, sizeof(act));	
+		act.sa_sigaction = SignalCatcher::signalHandler;
+		act.sa_flags = SA_SIGINFO;
+		
+		if (sigaction(sig, &act, 0) == -1) 
+		{
+			Out(SYS_GEN|LOG_IMPORTANT) << "Failed to set signal handler for " << sig << endl;
+			return false;
+		}
+		
+		return true;
+	}
+
+	void SignalCatcher::handleInput(int fd)
+	{
+		int sig = 0;
+		::read(fd, &sig, sizeof(int));
+		
+		Out(SYS_GEN|LOG_IMPORTANT) << "Signal " <<  sig << " caught " << endl;
+		emit triggered();
+	}
+
 
 }
 
