@@ -121,7 +121,7 @@ public:
 	{
 	}
 	
-public slots:
+public Q_SLOTS:
 	void accepted()
 	{
 		incoming = srv.acceptedConnection().toStrongRef();
@@ -133,7 +133,7 @@ public slots:
 		exit();
 	}
 	
-private slots:
+private Q_SLOTS:
 	void initTestCase()
 	{
 		bt::InitLog("packetlosstest.log");
